# risc-python

Python client and CLI for [RISC](https://riscnetworks.com/)

[![PyPI](https://img.shields.io/pypi/v/risc) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/risc)](https://pypi.org/project/risc/) [![PyPi Publish](https://github.com/2ndWatch/risc-python/workflows/PyPi%20Publish/badge.svg)](https://2ndwatch.github.io/risc-python/) [![Documenation](https://github.com/2ndWatch/risc-python/workflows/Github%20Pages/badge.svg)](https://2ndwatch.github.io/risc-python/)

## Requirements

[Python 3.6+](https://www.python.org/downloads/)

## Installation & Usage

```sh
pyenv install 3.7
pip(env) install risc
```
